def GetTSatPd(payload):
    """
    Thans to Daniel Mentel
    Function for displaying saturation temperatures for target and actual Pd, returned as array
    payload - register from 241 to 261
    :return:
    """
    if len(payload) == 22:
        tab=[]
        tab_4bit=[f'{divmod(int(hex(payload[6]),16), 256)[1]:08b}'[4:], f'{divmod(int(hex(payload[6]), 16), 256)[1]:08b}'[0:4]]
        b4f_8bit=f'{divmod(int(hex(payload[7]), 16), 256)[0]:08b}'
        b50_8bit=f'{divmod(int(hex(payload[7]), 16), 256)[1]:08b}'
        b4f = int(str(tab_4bit[0])+str(b4f_8bit), 2)
        if (b4f > 2047) :
            b4f -= 4095
        tab.append(b4f/10)
        b50 = int(str(tab_4bit[1])+str(b50_8bit), 2)
        if (b50 > 2047) :
            b50 -= 4095
        tab.append(b50/10)
        return tab
    else:
        return "Bad payload length"



def SetDHWTemp(current,new):
    try:
        newtemp = []
        newtemp.append(int(hex(current[0])[4:6], 16))
        newtemp.append(current[1])
        newtemp.append(int(hex(current[2])[2:6], 16))
        newtemp.append(int(hex(current[3])[4:6], 16))
        newtemp.append(512 + int(hex(current[4])[4:6], 16))
        newtemp.append(int(str(hex(int(new * 2)) + hex(current[5])[4:6]), 16))
        return newtemp
    except ValueError:
        return "ERROR"


def Get3way(payload):
    """
    Function for displaying if pump is on or off
    payload - register from 141 to 157
    :return:
    """
    if len(payload) == 16:
        tmp = divmod(int(hex(payload[0]), 16), 256)[0]
        if tmp == 4:
            threeway = 'CH'
        elif tmp == 6 or tmp == 0:
            threeway = 'DHW'
        else:
            threeway = 'ERR'
        return threeway
    else:
        return "Bad payload length"



def GetEEVLevel(payload):
    """
    Function for displaying EEV open level
    payload - register from 241 to 261
    :return:
    """
    if len(payload) == 22:
        eevlevel = divmod(int(hex(payload[5]), 16), 256)[0]
        return eevlevel
    else:
        return "Bad payload length"



from PyHaier.GetCHTemp import GetCHTemp
from PyHaier.SetCHTemp import SetCHTemp
from PyHaier.GetMode import GetMode
from PyHaier.SetMode import SetMode
from PyHaier.GetDHWTemp import GetDHWTemp
from PyHaier.GetDHWCurTemp import GetDHWCurTemp
from PyHaier.SetDHWTemp import SetDHWTemp
from PyHaier.GetState import GetState
from PyHaier.SetState import SetState
from PyHaier.GetTwiTwo import GetTwiTwo
from PyHaier.GetTdTs import GetTdTs
from PyHaier.GetPdPs import GetPdPs
from PyHaier.GetCompInfo import GetCompInfo
from PyHaier.GetArchError import GetArchError
from PyHaier.GetEEVLevel import GetEEVLevel
from PyHaier.GetFanRpm import GetFanRpm
from PyHaier.GetTao import GetTao
from PyHaier.GetPump import GetPump
from PyHaier.Get3way import Get3way
from PyHaier.GetThiTho import GetThiTho
from PyHaier.GetError import GetError



def SetMode(payload):

    if payload == "eco":
        mode=0
    elif payload == "quiet":
        mode=1
    elif payload == "turbo":
        mode=2
    else:
        return -1

    newmode=[]
    newmode.append(256+int(mode))
    return newmode


def GetState(payload):
    """
    Mode display function
    :return:
    """
    if len(payload) == 6:
        state=hex(payload[0])[4:6]
        if state == "00":
            output = "OFF"
        elif state == "01":
            output = "ON"
        elif state == "03":
            output="Cool ON"
        elif state == "05":
            output="Heat ON"
        elif state == "87":
            output="Tank ON"
        elif state == "83":
            output="Cool+Tank ON"
        elif state == "85":
            output="Heat+Tank ON"
        elif state == "02":
            output="Cool OFF"
        elif state == "04":
            output="Heat OFF"
        elif state == "86":
            output="Tank OFF"
        elif state == "82":
            output="Cool+Tank OFF"
        elif state == "84":
            output="Heat+Tank OFF"
        else:
            output="State Undefinde"

        return output
    else:
        return "Bad payload length"
